GINZICUT - NNTP Test Server for GINZIBIX

This is light-weight & stripped down python3 re-implementation of the python2-based nntp-server

       https://github.com/jpm/papercut

Copyright (c) 2018 Stephan Untergrabner, 2002 Joao Prado Maia <jpm@impleo.net>
     


GINZICUT requires python >= 3.7.2 !!!


INSTALL:

	A. distutils - in virtual environments:

		create/activate virtual environment

		a. Easiest: from PyPi	
		- pip install ginzicut

		b. Install directly from github with pip
		- pip install git+https://github.com/dermatty/GINZICUT.git#egg=ginzicut

		a. Local Install
		- clone this repo & unpack
		- cd to directory of repo
		- pip install .

	B. distutils - for a dedicated user:
		python3.7 -m pip install --user ginzicut

    C. Gentoo ebuild
        - add dermatty_overlay with layman (see overlay github site for instructions)
        - emerge -a ginzicut
